@@ -2,7 +2,7 @@
 #' @export
 #'
 #' @description Analyzes health history data loaded using \emph{load_phy}. Searches health history columns for a specified set of codes.
-#' By default, the data.table is returned with new columns corresponding to boolean values, whether given group of diagnoses are present in the given diagnosis.
+#' By default, the data.table is returned with new columns corresponding to boolean values, whether given group of health history data are present within the respective columns.
 #' If \emph{collapse} is given, then the information is aggregated based-on the \emph{collapse} column and the earliest of latest time of the given diagnosis is provided.
 #'
 #'
@@ -13,11 +13,10 @@
 #' The function searches for the given health history code type and code pair and adds new boolean columns with the name of each list element.
 #' These columns are indicators whether any of the health history code type and code pair occurs in the set of codes.
 #' @param collapse string, a column name on which to collapse the data.table.
-#' Used in case we wish to assess whether given health history codes are present within all the same instances of \emph{collapse}. See vignette for details.
+#' Used in case we wish to assess whether multiple health history codes are present within all the same instances of \emph{collapse}. See vignette for details.
 #' @param code_time string, column name of the time column. Defaults to \emph{time_phy}. Used in case collapse is present to provide the earliest or latest instance of health history information.
-#' @param time_type string, if multiple health histories are present within the same case of \emph{collapse}, which timepoint to return. Supported are: "earliest" or "latest". Defaults to \emph{earliest}.
-#' @param nThread integer, number of threads to use by \emph{dopar} for parallelization. If it is set to 1, then no parallel backends are created and the function is executed sequentially.
-#' On windows machines sockets are used, while on other operating systems fork parallelization is used.
+#' @param aggr_type string, if multiple health histories are present within the same case of \emph{collapse}, which timepoint to return. Supported are: "earliest" or "latest". Defaults to \emph{earliest}.
+#' @param nThread integer, number of threads to use for parallelization. If it is set to 1, then no parallel backends are created and the function is executed sequentially.
 #'
 #' @return data.table, with indicator columns whether the any of the given health histories are reported.
 #' If \emph{collapse} is present, then only unique ID and the summary columns are returned.
@@ -32,11 +31,11 @@
 #' #Search for for Height and Weight codes and summarize per patient providing earliest time
 #' anthropometrics <- list(Weight = c("LMR:3688", "EPIC:WGT"), Height = c("LMR:3771", "EPIC:HGT"))
 #' data_phy_parse <- convert_phy(d = data_phy, codes_to_find = anthropometrics, nThread = 2,
-#' collapse = "ID_MERGE", time_type = "earliest")
+#' collapse = "ID_MERGE", aggr_type = "earliest")
 #' }
 
 convert_phy <- function(d, code = "phy_code", code_type = "phy_code_type",  codes_to_find = NULL,
-                        collapse = NULL, code_time = "time_phy", time_type = "earliest", nThread = parallel::detectCores()-1) {
+                        collapse = NULL, code_time = "time_phy", aggr_type = "earliest", nThread = parallel::detectCores()-1) {
 
   .SD=.N=.I=.GRP=.BY=.EACHI=..=..cols=.SDcols=i=j=time_to_db=..which_ids_to=..which_ids_from=combined=..collapse=. <- NULL
 
@@ -45,11 +44,7 @@ convert_phy <- function(d, code = "phy_code", code_type = "phy_code_type",  code
     `%exec%` <- foreach::`%do%`
   } else {
     if(length(codes_to_find) > 0 & length(codes_to_find) < nThread) {nThread <- length(codes_to_find)}
-    if(.Platform$OS.type == "windows") {
-      cl <- parallel::makeCluster(nThread, outfile = "", type = "PSOCK", methods = FALSE, useXDR = FALSE)
-    } else{
-      cl <- parallel::makeCluster(nThread, outfile = "", type = "FORK", methods = FALSE, useXDR = FALSE)
-    }
+    cl <- parallel::makeCluster(nThread, methods = FALSE, useXDR = FALSE)
     doParallel::registerDoParallel(cl)
     `%exec%` <- foreach::`%dopar%`
   }
@@ -76,7 +71,7 @@ convert_phy <- function(d, code = "phy_code", code_type = "phy_code_type",  code
         comb[, names(codes_to_find[i]) := any(.SD %in% unlist(codes_to_find[i])), .SDcols = "combined", by=1:nrow(comb)]
         ID_dt <- unique(comb[, collapse, with = FALSE]) #Get IDs
 
-        if(time_type == "earliest") { #Find time
+        if(aggr_type == "earliest") { #Find time
           diag_coll <- comb[, .(var_time = min(get(code_time))), by=c(collapse, names(codes_to_find[i]))]
         } else {
           diag_coll <- comb[, .(var_time = max(get(code_time))), by=c(collapse, names(codes_to_find[i]))]
