@@ -12,7 +12,6 @@
 #' In other cases the lengths are unchanged. Defaults to \emph{standard}.
 #' @param perc numeric, a number between 0-1 indicating which parsed ID columns to keep. Columns present in \emph{perc x 100\%} of patients have are kept.
 #' @param nThread integer, number of threads to use by \emph{dopar} for parallelization. If it is set to 1, then no parallel backends are created and the function is executed sequentially.
-#' On windows machines sockets are used, while on other operating systems fork parallelization is used.
 
 #' @return data table, with columns corresponding to MRNs in the string of delimited list of values.
 #'
@@ -27,11 +26,7 @@ parse_ids <- function(str, num = NULL, sep = ":", id_length = "standard", perc =
   if(nThread == 1) {
     `%exec%` <- foreach::`%do%`
   } else {
-    if(.Platform$OS.type == "windows") {
-      cl <- parallel::makeCluster(nThread, outfile = "", type = "PSOCK", methods = FALSE, useXDR = FALSE)
-    } else{
-      cl <- parallel::makeCluster(nThread, outfile = "", type = "FORK", methods = FALSE, useXDR = FALSE)
-    }
+    cl <- parallel::makeCluster(nThread, methods = FALSE, useXDR = FALSE)
     doParallel::registerDoParallel(cl)
     `%exec%` <- foreach::`%dopar%`
   }
