@@ -6,7 +6,7 @@
 ## Date: 2023-02-24
 ###############################################################################
 
-testthat::skip_on_cran()
+testthat::skip_if_offline()
 # Load and check equality ====================
 suppressPackageStartupMessages(library(parseRPDR))
 
